@@ -16,13 +16,15 @@ class RunArgs:
 
         self.text = parent.text
         self.root = parent.root
+        self.gotoline = parent.gotoline
 
         parent.add_adv_menu('Run with args', self.Run, sp=True)
 
     def Run(self): # TODO 有没有更优雅的方法？
         args = askstring('Run with args', 'args:', parent=self.root)
         if args is not None:
-            self.text.insert('1.0', "__import__('sys').argv.append({args!r})\n\n".format(args=args))
+            self.text.insert('1.0', "__import__('sys').argv.append(%r)\n\n" % args)
+            self.gotoline(1)
 
 
 if __name__ == '__main__': # for test
